@@ -1,7 +1,10 @@
 mod async_stack;
+mod async_stack_action;
+mod error;
 mod result;
 mod stack;
 
 pub use async_stack::*;
+pub use error::*;
 pub use result::*;
 pub use stack::*;
